@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2019 Leandro Nini
+ * Copyright 2011-2021 Leandro Nini
  * Copyright 2000 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,9 @@
 #include "ini/types.h"
 #include "ini/iniHandler.h"
 
+#include "sidlib_features.h"
+
+#include <sidplayfp/sidplayfp.h>
 #include <sidplayfp/SidConfig.h>
 
 /*
@@ -60,8 +63,8 @@ public:
     struct audio_section
     {   // INI Section - [Audio]
         int frequency;
-        SidConfig::playback_t playback;
-        int  precision;
+        int channels;
+        int precision;
     };
 
     struct emulation_section
@@ -71,7 +74,9 @@ public:
         bool          modelForced;
         SidConfig::sid_model_t  sidModel;
         bool          forceModel;
+#ifdef FEAT_CONFIG_CIAMODEL
         SidConfig::cia_model_t  ciaModel;
+#endif
         bool          digiboost;
         bool          filter;
         double        bias;
