@@ -275,7 +275,8 @@ std::string ConsolePlayer::getFileName(const SidTuneInfo *tuneInfo, const char*
     if (m_outfile != NULL)
     {
         title = m_outfile;
-        if (title.find_last_of('.') == std::string::npos)
+        if (title.compare("-") != 0
+                && title.find_last_of('.') == std::string::npos)
             title.append(ext);
     }
     else
@@ -703,7 +704,7 @@ bool ConsolePlayer::play ()
     {
     case playerRunning:
         m_driver.selected->write ();
-        // Deliberate run on
+        // fall-through
     case playerPaused:
         // Check for a keypress (approx 250ms rate, but really depends
         // on music buffer sizes).  Don't do this for high quiet levels
