@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2013-2014 Leandro Nini
+ * Copyright 2013-2017 Leandro Nini
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #ifdef _WIN32
 #  include <windows.h>
 #  include <shlobj.h>
+#  include <shlwapi.h>
 
 #ifdef UNICODE
 #  define _tgetenv _wgetenv
@@ -32,6 +33,15 @@
 #  define _tgetenv getenv
 #endif
 
+SID_STRING utils::getExecPath()
+{
+    HMODULE hModule = GetModuleHandle(NULL);
+    TCHAR path[MAX_PATH];
+    GetModuleFileName(hModule, path, MAX_PATH);
+    PathRemoveFileSpec(path);
+    return path;
+}
+
 SID_STRING utils::getPath()
 {
     SID_STRING returnPath;
